@@ -56,20 +56,31 @@ var group__controls =
     ] ],
     [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html", [
       [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#aee94efa9f560fa95fcd47cc497e2f3d9", null ],
-      [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194", null ],
       [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a73017258060539b2ea3cb6f2c37c16ee", null ],
+      [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194", null ],
       [ "~CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#afe950609c73dfa6de5a3cbef008fbeff", null ],
+      [ "attached", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
       [ "closeWindow", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6fcb05de762da60f52d18d665c3b67d8", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a79e674b14bc222779b90738ef8f6e096", null ],
+      [ "getAnimationTime", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a22ba26e8b6dd9b87e7b2b3aa0f94c7f6", null ],
+      [ "getBitmapOffset", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a2aa48d074f315f79c09bce205e653418", null ],
       [ "isWindowOpened", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a9bc4cc2b9ac1bb18a948e6e7e8177fb4", null ],
       [ "newCopy", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a4433ff4e66b32c32a4b90436e369ec39", null ],
       [ "nextPixmap", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a7ca3bf73f0d19f84079ddd869582f150", null ],
       [ "onMouseDown", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a5dd3200e872b6337fa6eefe9599dd596", null ],
       [ "openWindow", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0231609979b47e5decfd68f1f198af02", null ],
       [ "previousPixmap", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#ae50a71e7927b3501b4ac0e461b4fee06", null ],
+      [ "removed", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a157ad241be4354121739aac80cf3cd3d", null ],
+      [ "setAnimationTime", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a97864020c1416b86454a8f12dc0f77f2", null ],
+      [ "setBackground", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab53c15f66b61201baec35c57d529cc42", null ],
+      [ "setBitmapOffset", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6ca87040eb789d3fbe39defcafcbe6e6", null ],
       [ "setNumSubPixmaps", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a12551d78e54ffd9dc479bd115633c0b1", null ],
+      [ "startTimer", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#aec53975ffc59ffaf3080db21af0d2f6e", null ],
+      [ "updateMinMaxFromBackground", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a255ab875415900d903c1be948d5d19df", null ],
+      [ "animationFrameTime", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a275bcd40970f1aaae9a958fd95d1e803", null ],
       [ "bWindowOpened", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#afd292af36cee8d646a779bd7c934111e", null ],
       [ "offset", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a8885308969382a38b3f72325fff3efc3", null ],
+      [ "timer", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab29cf11489df5f8869bdd1b4f5c8ef8e", null ],
       [ "totalHeightOfBitmap", "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a70252ffed7ec1cf8e1552751cab33c49", null ]
     ] ],
     [ "COnOffButton", "class_v_s_t_g_u_i_1_1_c_on_off_button.html", [
@@ -136,8 +147,8 @@ var group__controls =
     ] ],
     [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html", [
       [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html#afe8d19b0c1ca0fb19367b8a636a1a1e1", null ],
-      [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html#a5095b9dfa3ffbc29f542b225b97cc5a7", null ],
       [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html#af419b3350833b1669097ac320bc4819d", null ],
+      [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html#a5095b9dfa3ffbc29f542b225b97cc5a7", null ],
       [ "~CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html#aff494d1488548f3d455f9c78514e1769", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_kick_button.html#a79e674b14bc222779b90738ef8f6e096", null ],
       [ "newCopy", "class_v_s_t_g_u_i_1_1_c_kick_button.html#a4433ff4e66b32c32a4b90436e369ec39", null ],
@@ -277,8 +288,8 @@ var group__controls =
     ] ],
     [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html", [
       [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#aa4fe339a1b1b789b191573cc9e64f595", null ],
-      [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae39bb45e08ab3c4a4cfd51e724b876d3", null ],
       [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a5795a2c0eb736f15b0d448b8bfacd396", null ],
+      [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae39bb45e08ab3c4a4cfd51e724b876d3", null ],
       [ "~CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#af3a85d751115283a651e12bf590813a1", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a2223292a91c85ab8ff9d156763543bf2", null ],
       [ "getInverseBitmap", "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a3d2866628b30e10e9a04e02bf81ce090", null ],
@@ -292,8 +303,8 @@ var group__controls =
     ] ],
     [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html", [
       [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html#ae392f53b05d4ea79016ad81478b1cdce", null ],
-      [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html#a984cefdcb821e40134c505f9215f9953", null ],
       [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html#aa55ad59368588880245690611b6e9c76", null ],
+      [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html#a984cefdcb821e40134c505f9215f9953", null ],
       [ "~CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html#abcc2084107934b30dee9c0f3d2905703", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_movie_button.html#a79e674b14bc222779b90738ef8f6e096", null ],
       [ "newCopy", "class_v_s_t_g_u_i_1_1_c_movie_button.html#a4433ff4e66b32c32a4b90436e369ec39", null ],
@@ -478,8 +489,8 @@ var group__controls =
     ] ],
     [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html", [
       [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#a75026ef0ac47437080e19bf3e73da18b", null ],
-      [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#a902c9b1dd24b5fa94403f1f2cd6ef9c7", null ],
       [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#abfa918c0d08e9ce15907d0b124bd462a", null ],
+      [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#a902c9b1dd24b5fa94403f1f2cd6ef9c7", null ],
       [ "~CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#adf8d7b2549305ab5d68bc2d5e3359ea4", null ],
       [ "calcNormFromPoint", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#af3d757bcf461ed572120000455e285d7", null ],
       [ "calculateCoef", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html#ab6175b8b8abb1d09876c31ca1f520907", null ],
@@ -488,8 +499,8 @@ var group__controls =
     ] ],
     [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html", [
       [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#aacc21989b74b05f3cd0f48bc5d2f2a8f", null ],
-      [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#a1c5f65d23c6ead3113ddd99a91e40852", null ],
       [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#a84f1ef44c839b7efebf5771f7e7b13f8", null ],
+      [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#a1c5f65d23c6ead3113ddd99a91e40852", null ],
       [ "~CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#a13014b25c33dc7fa244011cb030ae57f", null ],
       [ "calcNormFromPoint", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#af3d757bcf461ed572120000455e285d7", null ],
       [ "calculateCoef", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#ab6175b8b8abb1d09876c31ca1f520907", null ],
@@ -502,8 +513,8 @@ var group__controls =
         [ "kVertical", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#addb2fa415e015ee482fa2cd9eba96af7a4764485d9d221af213bf2b2769cdfc54", null ]
       ] ],
       [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a38b2529c6253684c15a3ff511d78d8de", null ],
-      [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a9e7d043e454ed4dfe4d25d6799fe791d", null ],
       [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a2f5e6604ed6dfdf8a5fd0004ba3d775a", null ],
+      [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a9e7d043e454ed4dfe4d25d6799fe791d", null ],
       [ "~CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#af879403805fdbdb957ac838f9a336f4d", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a79e674b14bc222779b90738ef8f6e096", null ],
       [ "newCopy", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html#a4433ff4e66b32c32a4b90436e369ec39", null ],
