@@ -58,10 +58,10 @@ var searchData=
   ['modelinear',['modeLinear',['../struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html#a5dd378c7e92a12e38e3e08c2d91ba5db',1,'VSTGUI::CKnobBase::MouseEditingState']]],
   ['modifier',['modifier',['../struct_vst_key_code.html#ae3f31c0d691c7a842dbddc35afe1e4e5',1,'VstKeyCode']]],
   ['modifierevent',['ModifierEvent',['../struct_v_s_t_g_u_i_1_1_modifier_event.html',1,'VSTGUI']]],
-  ['modifierkey',['ModifierKey',['../namespace_v_s_t_g_u_i.html#a51910458d0a923b29f1694654d8eb00a',1,'VSTGUI']]],
+  ['modifierkey',['ModifierKey',['../group__new__in__4__11.html#ga51910458d0a923b29f1694654d8eb00a',1,'VSTGUI']]],
   ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html',1,'VSTGUI']]],
-  ['modifiers',['modifiers',['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)']]],
-  ['mousebutton',['MouseButton',['../namespace_v_s_t_g_u_i.html#ab8d93bdfbb0fd7ae143bbfda46bf38bc',1,'VSTGUI']]],
+  ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)'],['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()']]],
+  ['mousebutton',['MouseButton',['../group__new__in__4__11.html#gab8d93bdfbb0fd7ae143bbfda46bf38bc',1,'VSTGUI']]],
   ['mousecancelevent',['MouseCancelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html',1,'VSTGUI']]],
   ['mousecancelevent',['MouseCancelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html#a972937b504a1b35085f6e5204f18e638',1,'VSTGUI::MouseCancelEvent']]],
   ['mousechangestartpoint',['mouseChangeStartPoint',['../class_v_s_t_g_u_i_1_1_c_x_y_pad.html#a6c9058da80a96badc514fd34a47e5761',1,'VSTGUI::CXYPad']]],
