@@ -3,10 +3,13 @@ var searchData=
   ['version_204_2e0',['Version 4.0',['../group__new__in__4__0.html',1,'']]],
   ['version_204_2e1',['Version 4.1',['../group__new__in__4__1.html',1,'']]],
   ['version_204_2e10',['Version 4.10',['../group__new__in__4__10.html',1,'']]],
+  ['version_204_2e11',['Version 4.11',['../group__new__in__4__11.html',1,'']]],
+  ['version_204_2e12',['Version 4.12',['../group__new__in__4__12.html',1,'']]],
   ['version_204_2e2',['Version 4.2',['../group__new__in__4__2.html',1,'']]],
   ['version_204_2e3',['Version 4.3',['../group__new__in__4__3.html',1,'']]],
   ['version_204_2e5',['Version 4.5',['../group__new__in__4__5.html',1,'']]],
   ['version_204_2e7',['Version 4.7',['../group__new__in__4__7.html',1,'']]],
   ['version_204_2e9',['Version 4.9',['../group__new__in__4__9.html',1,'']]],
+  ['views_20using_20multi_2dframe_20bitmaps',['Views using Multi-Frame Bitmaps',['../group__uses__multi__frame__bitmaps.html',1,'']]],
   ['views',['Views',['../group__views.html',1,'']]]
 ];
